#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='seavatar',
      version='0.1.1',
      description='Tool To Generate Beach themed -MLH avatars',
      author='Victor Prince',
      author_email='v1kk1x@protonmail.com',
      url='https://github.com/victorprince/Seavatar',
      py_modules=['seavatar'],
     )
